==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/ui/input/model/GearComboModel.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: GearComboModel.java 3276 2011-04-20 15:36:48Z chatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/isis-fish/tags/isis-fish-4.2.0.1/src/main/java/fr/ifremer/isisfish/ui/input/model/GearComboModel.java $
 * %%
 * Copyright (C) 2011 Ifremer, CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.model;

import java.util.List;

import javax.swing.DefaultComboBoxModel;

import fr.ifremer.isisfish.entities.Gear;

/**
 * Model pour la liste des {@link Gear}.
 * 
 * Pas de selection par defaut.
 *
 * @author chatellier
 * @version $Revision: 3276 $
 * 
 * Last update : $Date: 2011-04-20 17:36:48 +0200 (Wed, 20 Apr 2011) $
 * By : $Author: chatellier $
 */
public class GearComboModel extends DefaultComboBoxModel {

    /** serialVersionUID. */
    private static final long serialVersionUID = 6171850179969290032L;

    /** Species list */
    protected List<Gear> gearList;

    /**
     * Constructor with gears list.
     * 
     * @param gearList gears list
     */
    public GearComboModel(List<Gear> gearList) {
        this.gearList = gearList;
    }

    /*
     * @see javax.swing.ListModel#getElementAt(int)
     */
    @Override
    public Object getElementAt(int index) {
        return gearList.get(index);
    }

    /*
     * @see javax.swing.ListModel#getSize()
     */
    @Override
    public int getSize() {
        int size = 0;

        if (gearList != null) {
            size = gearList.size();
        }
        return size;
    }
}

==> isis-fish-4.3.0.0-sources.jar: fr/ifremer/isisfish/ui/input/model/GearComboModel.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: GearComboModel.java 3969 2014-04-17 16:48:13Z echatellier $
 * $HeadURL: https://svn.codelutin.com/isis-fish/tags/isis-fish-4.3.0.0/src/main/java/fr/ifremer/isisfish/ui/input/model/GearComboModel.java $
 * %%
 * Copyright (C) 2011 Ifremer, CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.model;

import java.util.List;

import javax.swing.DefaultComboBoxModel;

import fr.ifremer.isisfish.entities.Gear;

/**
 * Model pour la liste des {@link Gear}.
 * 
 * Pas de selection par defaut.
 *
 * @author chatellier
 * @version $Revision: 3969 $
 * 
 * Last update : $Date: 2014-04-17 18:48:13 +0200 (Thu, 17 Apr 2014) $
 * By : $Author: echatellier $
 */
public class GearComboModel extends DefaultComboBoxModel<Gear> {

    /** serialVersionUID. */
    private static final long serialVersionUID = 6171850179969290032L;

    /** Species list */
    protected List<Gear> gearList;

    /**
     * Constructor with gears list.
     * 
     * @param gearList gears list
     */
    public GearComboModel(List<Gear> gearList) {
        this.gearList = gearList;
    }

    /*
     * @see javax.swing.ListModel#getElementAt(int)
     */
    @Override
    public Gear getElementAt(int index) {
        return gearList.get(index);
    }

    /*
     * @see javax.swing.ListModel#getSize()
     */
    @Override
    public int getSize() {
        int size = 0;

        if (gearList != null) {
            size = gearList.size();
        }
        return size;
    }
}
